@@ -51,6 +51,8 @@ class CANTOR_EXPORT DefaultVariableModel : public QAbstractTableModel
 
 public:
 
+    enum {DataRole = Qt::UserRole + 1};
+
     /**
      * A structure representing a variable.
      */
@@ -76,7 +78,7 @@ public:
      * @param session the session this Model belongs to, also becomes the Model's parent.
      */
     explicit DefaultVariableModel(Session* session);
-    ~DefaultVariableModel() override = default;
+    ~DefaultVariableModel() override;
 
     /**
      * Get the session which created this Model and whose variables it contains
